@@ -2,6 +2,7 @@ package HTTP::Session::Store::Memcached;
 use strict;
 use warnings;
 use base qw/Class::Accessor::Fast/;
+use Encode;
 
 __PACKAGE__->mk_ro_accessors(qw/memd expires/);
 
@@ -20,7 +21,8 @@ sub new {
 
 sub _filter_sid($) {
     my $session_id = shift;
-    if ($session_id =~ /[\0\r\n]/ || length($session_id) > 250) {
+    $session_id = Encode::encode_utf8($session_id) if Encode::is_utf8($session_id);
+    if ($session_id =~ /[\x00-\x20\x7f-\xff]/ || length($session_id) > 250) {
         die "detected memcached injection: $session_id";
     }
     return $session_id;
